%global vcu_maj 12
%global vcu_min 1 

Name:           torch-vision
Version:        0.15.2
Release:        1%{dist}
Summary:        Datasets, Transforms and Models specific to Computer Vision
License:        BSD
Source0:        vision-0.15.2.tar.gz 
URL:            https://github.com/pytorch/vision

BuildRequires:  python3-devel python3-setuptools git
BuildRequires:  python3-numpy pytorch-devel pytorch-python3
BuildRequires:  ninja-build python3-typing-extensions glog-devel
BuildRequires:  libpng-devel libjpeg-turbo-devel

%define have_cuda 1
%define have_cuda_gcc 0 
%define gpu_target_ptx "50"
%ifarch aarch64
%define gpu_target_bin 50,52,53,60,61,62,70,75,80,86,90
%else
%define gpu_target_bin 50,52,60,61,70,75,80,86,90
%endif

%if %{have_cuda}
%if %{have_cuda_gcc}
BuildRequires:  cuda-gcc-c++
%endif
BuildRequires:  cuda-nvcc-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvtx-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-cupti-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvprune-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-cudart-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvml-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-nvrtc-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-driver-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  cuda-profiler-api-%{vcu_maj}-%{vcu_min}
BuildRequires:  nvidia-driver-cuda-libs
BuildRequires:  libnpp-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcurand-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcusparse-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcublas-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcusolver-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcufft-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libcurand-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libnvjpeg-devel-%{vcu_maj}-%{vcu_min}
BuildRequires:  libnccl-devel
Requires:  cuda-cudart-%{vcu_maj}-%{vcu_min}
Requires:  cuda-nvrtc-%{vcu_maj}-%{vcu_min}
Requires:  cuda-nvtx-%{vcu_maj}-%{vcu_min}
%endif

%description
Datasets, Transforms and Models specific to Computer Vision.

%package        python3
Summary:        %{summary}
Provides:       torch-vision
Requires:       pytorch-python3 python3-numpy python3-requests
Requires:       python3-typing-extensions python3-pillow

%description    python3
Datasets, Transforms and Models specific to Computer Vision.


%prep
%setup -n vision-%{version} 
sed -i -e "s|ffmpeg_root, 'include'|ffmpeg_root, 'include/ffmpeg'|" setup.py

%build
set +x
gencode=""
for a in {%{gpu_target_bin}}; do
  gencode=$gencode"-gencode=arch=compute_$a,code=compute_$a "
done
for a in %{gpu_target_ptx}; do
  gencode=$gencode"-gencode=arch=compute_$a,code=sm_$a"
done

export NVCC_FLAGS="$gencode --compiler-options -fPIC -Wno-deprecated-gpu-targets -allow-unsupported-compiler --fatbin-options -compress-all"
%if %{have_cuda_gcc}
export NVCC_FLAGS="$NVCC_FLAGS -ccbin %{_bindir}/cuda-gcc"
%endif

mkdir -p build
export FORCE_CUDA=1
export MAX_JOBS=%{_smp_build_ncpus}
export CUDA_HOME=/usr/local/cuda-%{vcu_maj}.%{vcu_min}
export LD_LIBRARY_PATH=/usr/local/cuda-%{vcu_maj}.%{vcu_min}/lib64/
%{__python3} setup.py build


%install
export FORCE_CUDA=1
export CUDA_HOME=/usr/local/cuda-%{vcu_maj}.%{vcu_min}
export LD_LIBRARY_PATH=/usr/local/cuda-%{vcu_maj}.%{vcu_min}/lib64/
%{__python3} setup.py install --skip-build --root %{buildroot}
sed -i 's|[!<=>].*||g' %{buildroot}%{python3_sitearch}/*.egg-info/requires.txt


%files python3
%{python3_sitearch}/*
%license LICENSE


%changelog
* Fri Jul 28 2023 flin <flin@linux.alibaba.com> - 0.15.2-1
- Init torch vision for anolis
